#!/usr/bin/env python

import os
from nistp224 import *

"""This module tests the py-nistp224 module.

It runs some of the same tests as rts.tests.
"""

__author__ = 'Faried Nawaz'
__version__ = '1.0'


def read_data(fnames):
    """Read in files.

    Returns a dict.  Key is the filename with everything before
    the `.' stripped away, value is the data.
    """

    ret = {}
    for name in fnames:
        n = name.split('.')[1]
        ret[n] = open(name, 'r').read()

    return ret


def run_tests():
    """Test if the python interface really works."""

    # first, we load the files.
    sec = read_data(['SECRET.alice', 'SECRET.bob', 'SECRET.charlie',
                     'SECRET.dave', 'SECRET.infinity'])

    pub = read_data(['PUBLIC.alice', 'PUBLIC.bob', 'PUBLIC.charlie',
                     'PUBLIC.dave', 'PUBLIC.infinity'])

    pub56 = read_data(['PUBLIC56.alice', 'PUBLIC56.bob', 'PUBLIC56.charlie',
                       'PUBLIC56.dave'])

    shared = read_data(['SHARED.ab', 'SHARED.ac', 'SHARED.ad',
                        'SHARED.bc', 'SHARED.bd',
                        'SHARED.cd'])

    shared56 = read_data(['SHARED56.ab', 'SHARED56.ac', 'SHARED56.ad',
                        'SHARED56.bc', 'SHARED56.bd',
                        'SHARED56.cd'])

    # hack.  can't use the same dict for these two because their
    # keys clash.
    #    st = read_data(['STANDARD.base'])
    #   st56 = read_data(['STANDARD56.base'])
    st = standard_base
    st56 = standard56_base
 

    ret = 0
    ret = ret + (nistp224(st, sec['alice']) == pub['alice'])
    ret = ret + (nistp224(st, sec['bob']) == pub['bob'])
    ret = ret + (nistp224(st, sec['charlie']) == pub['charlie'])
    ret = ret + (nistp224(st, sec['dave']) == pub['dave'])
    ret = ret + (nistp224(st, sec['infinity']) == pub['infinity'])
    if ret == 5:
        print '--- nistp224 generates public keys correctly'


    ret = 0
    ret = ret + (nistp224(pub['bob'], sec['alice']) == shared['ab'])
    ret = ret + (nistp224(pub['charlie'], sec['alice']) == shared['ac'])
    ret = ret + (nistp224(pub['dave'], sec['alice']) == shared['ad'])
    ret = ret + (nistp224(pub['alice'], sec['bob']) == shared['ab'])
    ret = ret + (nistp224(pub['charlie'], sec['bob']) == shared['bc'])
    ret = ret + (nistp224(pub['dave'], sec['bob']) == shared['bd'])
    ret = ret + (nistp224(pub['alice'], sec['charlie']) == shared['ac'])
    ret = ret + (nistp224(pub['bob'], sec['charlie']) == shared['bc'])
    ret = ret + (nistp224(pub['dave'], sec['charlie']) == shared['cd'])
    ret = ret + (nistp224(pub['alice'], sec['dave']) == shared['ad'])
    ret = ret + (nistp224(pub['bob'], sec['dave']) == shared['bd'])
    ret = ret + (nistp224(pub['charlie'], sec['dave']) == shared['cd'])
    if ret == 12:
        print '--- nistp224 generates shared secrets correctly'
        

    ret = 0
    ret = ret + (nistp224_56(st56, sec['alice']) == pub56['alice'])
    ret = ret + (nistp224_56(st56, sec['bob']) == pub56['bob'])
    ret = ret + (nistp224_56(st56, sec['charlie']) == pub56['charlie'])
    if ret == 3:
        print '--- nistp224-56 generates public keys correctly'

    ret = 0
    ret = ret + (nistp224_56(pub56['bob'], sec['alice']) == shared56['ab'])
    ret = ret + (nistp224_56(pub56['charlie'], sec['alice']) == shared56['ac'])
    ret = ret + (nistp224_56(pub56['dave'], sec['alice']) == shared56['ad'])
    ret = ret + (nistp224_56(pub56['alice'], sec['bob']) == shared56['ab'])
    ret = ret + (nistp224_56(pub56['charlie'], sec['bob']) == shared56['bc'])
    ret = ret + (nistp224_56(pub56['dave'], sec['bob']) == shared56['bd'])
    ret = ret + (nistp224_56(pub56['alice'], sec['charlie']) == shared56['ac'])
    ret = ret + (nistp224_56(pub56['bob'], sec['charlie']) == shared56['bc'])
    ret = ret + (nistp224_56(pub56['dave'], sec['charlie']) == shared56['cd'])
    ret = ret + (nistp224_56(pub56['alice'], sec['dave']) == shared56['ad'])
    ret = ret + (nistp224_56(pub56['bob'], sec['dave']) == shared56['bd'])
    ret = ret + (nistp224_56(pub56['charlie'], sec['dave']) == shared56['cd'])
    if ret == 12:
        print '--- nistp224-56 generates shared secrets correctly'


if __name__ == '__main__':
    os.chdir('/package/math/nistp224/compile')
    run_tests()
